/*
* Copyright (C) 2011 Sunil Mohan Adapa <sunil@medhas.org>.
* Copyright (C) 2011 O S K Chaitanya <oskchaitanya@gmail.com>.
*
* Author: Sunil Mohan Adapa <sunil@medhas.org>
*         O S K Chaitanya <oskchaitanya@gmail.com>
*
* This file is part of GNOME Nonogram.
*
* GNOME Nonogram is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* GNOME Nonogram is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with GNOME Nonogram. If not, see <http://www.gnu.org/licenses/>.
*/

const Gtk = imports.gi.Gtk;
const GObject = imports.gi.GObject;

LabelTable = new GType(_LabelTable = {
    parent: Gtk.Table.type,
    name: "LabelTable",

    class_init: function(klass, prototype) {
        prototype._populateData = _LabelTable._populateData;
        prototype.setData = _LabelTable.setData;
    },

    init: function() {
    },

    setData: function(data) {
        this.data = data;

        this.foreach(
            function(child) {
                child.get_parent().remove(child);
            }
        );
        this.resize(data.length, data[0].length);

        this._populateData();
        this.show_all();
    },

    _populateData: function() {
        var maxLength = 0;
        for(var i = 0; i < this.data.length; ++i) {
            if(maxLength < this.data[i].length)
                maxLength = this.data[i].length;
        }

        for(i = 0; i < this.data.length; ++i) {
            var array = this.data[i];

            for(var j = 0; j < maxLength; ++j) {
                var labelText = " ";
                var index = j - maxLength + array.length;
                if (index >= 0) {
                    labelText = array[index].count.toString();

                    var labelColor = array[index].color.toString(16);
                    labelColor = "00000000".slice(0, -labelColor.length)
                                    + labelColor;
                    labelColor = labelColor.slice(0, -2);

                    labelText = "<span color='#"
                                    + labelColor
                                    + "'><big>"
                                    + labelText
                                    + "</big></span>";
                }

                var label = new Gtk.Label({
                                              label: labelText,
                                              xalign: this.labelTextXAlign,
                                              use_markup: true
                                          });

                // Assuming orientation == "horizontal" by default
                var row = j;
                var col = i;

                if(this.orientation == "vertical") {
                    row = i;
                    col = j;
                }

                this.attach(label,
                            row, row+1, col, col+1,
                            Gtk.AttachOptions.EXPAND |
                            Gtk.AttachOptions.FILL,
                            Gtk.AttachOptions.EXPAND |
                            Gtk.AttachOptions.FILL,
                            0, 0);
            }
        }
    }
});


RowLabelTable = new GType({
    parent: LabelTable.type,
    name: "RowLabelTable",
    class_init: function(klass, prototype) {
        prototype.orientation = "horizontal";
        prototype.labelTextXAlign = 1.0;
    }
});


ColumnLabelTable = new GType({
    parent: LabelTable.type,
    name: "ColumnLabelTable",
    class_init: function(klass, prototype) {
        prototype.orientation = "vertical";
        prototype.labelTextXAlign = 0.5;
    }
});
