#!/usr/bin/env seed

/*
* Copyright (C) 2011 Sunil Mohan Adapa <sunil@medhas.org>.
* Copyright (C) 2011 O S K Chaitanya <oskchaitanya@gmail.com>.
*
* Author: Sunil Mohan Adapa <sunil@medhas.org>
*         O S K Chaitanya <oskchaitanya@gmail.com>
*
* This file is part of GNOME Nonogram.
*
* GNOME Nonogram is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* GNOME Nonogram is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with GNOME Nonogram. If not, see <http://www.gnu.org/licenses/>.
*/

const GdkPixbuf = imports.gi.GdkPixbuf;
const Gtk = imports.gi.Gtk;
const GtkBuilder = imports.gtkbuilder;

const Config = imports.config;

// Adding path to enable loading nonogram io seed module
imports.searchPath.unshift(imports.config.libdir);

const GameWidget = imports.gamewidget;
const LabelTable = imports.labeltable;
const PixelGrid = imports.pixelgrid;

var signalHandlers = {
    quit: Gtk.main_quit,
    about: about,
    newGame: newGame
};

var builder;
var aboutDialog;
var window;

function main() {
    Gtk.init(Seed.argv);

    builder = new Gtk.Builder();
    builder.add_from_file(imports.config.datadir + "/main-window.ui");
    builder.connect_signals(signalHandlers);

    window = builder.get_object("main_window");
    aboutDialog = builder.get_object("aboutdialog");
    aboutDialog.version = Config.version;

    window.show_all();

    Gtk.main();
}

function about() {
    aboutDialog.run();
    aboutDialog.hide();
}

function newGame() {
    var fileChooserDialog = new Gtk.FileChooserDialog();
    fileChooserDialog.set_title("Open image file for puzzle");
    fileChooserDialog.add_button("Cancel", Gtk.ResponseType.CANCEL);
    fileChooserDialog.add_button("Open", Gtk.ResponseType.ACCEPT);
    fileChooserDialog.set_action(Gtk.FileChooserAction.OPEN);
    fileChooserDialog.set_transient_for(window);

    var response = fileChooserDialog.run();

    if(response == Gtk.ResponseType.ACCEPT) {
        var filename = fileChooserDialog.get_filename();

        var gameWidget = builder.get_object("gamewidget");
        gameWidget.puzzleFile = filename;
    }

    fileChooserDialog.destroy();
}

main();
